pub struct EulerDiscreteSchedulerConfig {
pub beta_start: f64,
pub beta_end: f64,
pub beta_schedule: BetaSchedule,
pub train_timesteps: usize,
pub prediction_type: PredictionType,
}Fields
beta_start: f64The value of beta at the beginning of training.
beta_end: f64The value of beta at the end of training.
beta_schedule: BetaScheduleHow beta evolved during training.
train_timesteps: usizenumber of diffusion steps used to train the model.
prediction_type: PredictionTypeprediction type of the scheduler function