pub struct PNDMScheduler {
pub config: PNDMSchedulerConfig,
/* private fields */
}Expand description
Pseudo numerical methods for diffusion models (PNDM) proposes using more advanced ODE integration techniques, namely Runge-Kutta method and a linear multi-step method.
Fields
config: PNDMSchedulerConfigImplementations
Sourceimpl PNDMScheduler
impl PNDMScheduler
pub fn new(inference_steps: usize, config: PNDMSchedulerConfig) -> Self
pub fn timesteps(&self) -> &[usize]
Sourcepub fn scale_model_input(&self, sample: Tensor, _timestep: usize) -> Tensor
pub fn scale_model_input(&self, sample: Tensor, _timestep: usize) -> Tensor
Ensures interchangeability with schedulers that need to scale the denoising model input depending on the current timestep.
pub fn step( &mut self, model_output: &Tensor, timestep: usize, sample: &Tensor, ) -> Tensor
pub fn add_noise( &self, original: &Tensor, noise: Tensor, timestep: usize, ) -> Tensor
pub fn init_noise_sigma(&self) -> f64