Module transformers

Module transformers 

Transformers

The transformers module contains some basic implementation of transformers based models used to process the user prompt and generate the related embeddings. It also includes some simple tokenization.

Modules

clip
Contrastive Language-Image Pre-Training